# -*- coding: utf-8 -*-

_name1 = [
    'Turtwig', 'Grotle', 'Torterra', 'Chimchar', 'Monferno',
    'Infernape', 'Piplup', 'Prinplup', 'Empoleon', 'Starly',
    'Staravia', 'Staraptor', 'Bidoof', 'Bibarel', 'Kricketot',
    'Kricketune', 'Shinx', 'Luxio', 'Luxray', 'Budew',
    'Roserade', 'Cranidos', 'Rampardos', 'Shieldon', 'Bastiodon',
    'Burmy', 'Wormadam', 'Mothim', 'Combee', 'Vespiquen',
    'Pachirisu', 'Buizel', 'Floatzel', 'Cherubi', 'Cherrim',
    'Shellos', 'Gastrodon', 'Ambipom', 'Drifloon', 'Drifblim',
    'Buneary', 'Lopunny', 'Mismagius', 'Honchkrow', 'Glameow',
    'Purugly', 'Chingling', 'Stunky', 'Skuntank', 'Bronzor',
    'Bronzong', 'Bonsly', 'Mime Jr.',
]

_name2 = [
    'Happiny', 'Chatot', 'Spiritomb', 'Gible', 'Gabite',
    'Garchomp', 'Munchlax', 'Riolu', 'Lucario', 'Hippopotas',
    'Hippowdon', 'Skorupi', 'Drapion', 'Croagunk', 'Toxicroak',
    'Carnivine', 'Finneon', 'Lumineon', 'Mantyke', 'Snover',
    'Abomasnow', 'Weavile', 'Magnezone', 'Lickilicky', 'Rhyperior',
    'Tangrowth', 'Electivire', 'Magmortar', 'Togekiss', 'Yanmega',
    'Leafeon', 'Glaceon', 'Gliscor', 'Mamoswine', 'Porygon-Z',
    'Gallade', 'Probopass', 'Dusknoir', 'Froslass', 'Rotom',
    'Uxie', 'Mesprit', 'Azelf', 'Dialga', 'Palkia', 'Heatran',
    'Regigigas', 'Giratina', 'Cresselia', 'Phione', 'Manaphy',
    'Darkrai', 'Shaymin', 'Arceus',
]
