# -*- coding: utf-8 -*-

_name1 = [
    'Chespin', 'Quilladin', 'Chesnaught', 'Fennekin', 'Braixen',
    'Delphox', 'Froakie', 'Frogadier', 'Greninja', 'Bunnelby',
    'Diggersby', 'Fletchling', 'Fletchinder', 'Talonflame', 'Scatterbug',
    'Spewpa', 'Vivillon', 'Litleo', 'Pyroar', 'Flabebe',
    'Floette', 'Florges', 'Skiddo', 'Gogoat', 'Pancham',
    'Pangoro', 'Furfrou', 'Espurr', 'Meowstic', 'Honedge',
    'Doublade', 'Aegislash', 'Spritzee', 'Aromatisse', 'Swirlix',
    'Slurpuff',
]

_name2 = [
    'Inkay', 'Malamar', 'Binacle', 'Barbaracle', 'Skrelp',
    'Dragalge', 'Clauncher', 'Clawitzer', 'Helioptile', 'Heliolisk',
    'Tyrunt', 'Tyrantrum', 'Amaura', 'Aurorus', 'Sylveon',
    'Hawlucha', 'Dedenne', 'Carbink', 'Goomy', 'Sliggoo',
    'Goodra', 'Klefki', 'Phantump', 'Trevenant', 'Pumpkaboo',
    'Gourgeist', 'Bergmite', 'Avalugg', 'Noibat', 'Noivern',
    'Xerneas', 'Yveltal', 'Zygarde', 'Diancie', 'Hoopa',
    'Volcanion',
]
