# -*- coding: utf-8 -*-

_name1 = [
    'Victini', 'Snivy', 'Servine', 'Serperior', 'Tepig',
    'Pignite', 'Emboar', 'Oshawott', 'Dewott', 'Samurott',
    'Patrat', 'Watchog', 'Lillipup', 'Herdier', 'Stoutland',
    'Purrloin', 'Liepard', 'Pansage', 'Simisage', 'Pansear',
    'Simisear', 'Panpour', 'Simipour', 'Munna', 'Musharna',
    'Pidove', 'Tranquill', 'Unfezant', 'Blitzle', 'Zebstrika',
    'Roggenrola', 'Boldore', 'Gigalith', 'Woobat', 'Swoobat',
    'Drilbur', 'Excadrill', 'Audino', 'Timburr', 'Gurdurr',
    'Conkeldurr', 'Tympole', 'Palpitoad', 'Seismitoad', 'Throh',
    'Sawk', 'Sewaddle', 'Swadloon', 'Leavanny', 'Venipede',
    'Whirlipede', 'Scolipede', 'Cottonee', 'Whimsicott', 'Petilil',
    'Lilligant', 'Basculin', 'Sandile', 'Krokorok', 'Krookodile',
    'Darumaka', 'Darmanitan', 'Maractus', 'Dwebble', 'Crustle',
    'Scraggy', 'Scrafty', 'Sigilyph', 'Yamask', 'Cofagrigus',
    'Tirtouga', 'Carracosta', 'Archen', 'Archeops', 'Trubbish',
    'Garbodor', 'Zorua', 'Zoroark',
]

_name2 = [
    'Minccino', 'Cinccino', 'Gothita', 'Gothorita', 'Gothitelle',
    'Solosis', 'Duosion', 'Reuniclus', 'Ducklett', 'Swanna',
    'Vanillite', 'Vanillish', 'Vanilluxe', 'Deerling', 'Sawsbuck',
    'Emolga', 'Karrablast', 'Escavalier', 'Foongus', 'Amoonguss',
    'Frillish', 'Jellicent', 'Alomomola', 'Joltik', 'Galvantula',
    'Ferroseed', 'Ferrothorn', 'Klink', 'Klang', 'Klinklang',
    'Tynamo', 'Eelektrik', 'Eelektross', 'Elgyem', 'Beheeyem',
    'Litwick', 'Lampent', 'Chandelure', 'Axew', 'Fraxure',
    'Haxorus', 'Cubchoo', 'Beartic', 'Cryogonal', 'Shelmet',
    'Accelgor', 'Stunfisk', 'Mienfoo', 'Mienshao', 'Druddigon',
    'Golett', 'Golurk', 'Pawniard', 'Bisharp', 'Bouffalant',
    'Rufflet', 'Braviary', 'Vullaby', 'Mandibuzz', 'Heatmor',
    'Durant', 'Deino', 'Zweilous', 'Hydreigon', 'Larvesta',
    'Volcarona', 'Cobalion', 'Terrakion', 'Virizion', 'Tornadus',
    'Thundurus', 'Reshiram', 'Zekrom', 'Landorus', 'Kyurem',
    'Keldeo', 'Meloetta', 'Genesect',
]
