# -*- coding: utf-8 -*-

_name1 = [
    'Treecko', 'Grovyle', 'Sceptile', 'Torchic', 'Combusken',
    'Blaziken', 'Mudkip', 'Marshtomp', 'Swampert', 'Poochyena',
    'Mightyena', 'Zigzagoon', 'Linoone', 'Wurmple', 'Silcoon',
    'Beautifly', 'Cascoon', 'Dustox', 'Lotad', 'Lombre',
    'Ludicolo', 'Seedot', 'Nuzleaf', 'Shiftry', 'Taillow',
    'Swellow', 'Wingull', 'Pelipper', 'Ralts', 'Kirlia',
    'Gardevoir', 'Surskit', 'Masquerain', 'Shroomish', 'Breloom',
    'Slakoth', 'Vigoroth', 'Slaking', 'Nincada', 'Ninjask',
    'Shedinja', 'Whismur', 'Loudred', 'Exploud', 'Makuhita',
    'Hariyama', 'Azurill', 'Nosepass', 'Skitty', 'Delcatty',
    'Sableye', 'Mawile', 'Aron', 'Lairon', 'Aggron', 'Meditite',
    'Medicham', 'Electrike', 'Manectric', 'Plusle', 'Minun',
    'Volbeat', 'Illumise', 'Roselia', 'Gulpin', 'Swalot',
    'Carvanha', 'Sharpedo',
]

_name2 = [
    'Wailmer', 'Wailord', 'Numel', 'Camerupt', 'Torkoal',
    'Spoink', 'Grumpig', 'Spinda', 'Trapinch', 'Vibrava',
    'Flygon', 'Cacnea', 'Cacturne', 'Swablu', 'Altaria',
    'Zangoose', 'Seviper', 'Lunatone', 'Solrock', 'Barboach',
    'Whiscash', 'Corphish', 'Crawdaunt', 'Baltoy', 'Claydol',
    'Lileep', 'Cradily', 'Anorith', 'Armaldo', 'Feebas',
    'Milotic', 'Castform', 'Kecleon', 'Shuppet', 'Banette',
    'Duskull', 'Dusclops', 'Tropius', 'Chimecho', 'Absol',
    'Wynaut', 'Snorunt', 'Glalie', 'Spheal', 'Sealeo',
    'Walrein', 'Clamperl', 'Huntail', 'Gorebyss', 'Relicanth',
    'Luvdisc', 'Bagon', 'Shelgon', 'Salamence', 'Beldum',
    'Metang', 'Metagross', 'Regirock', 'Regice', 'Registeel',
    'Latias', 'Latios', 'Kyogre', 'Groudon', 'Rayquaza',
    'Jirachi', 'Deoxys',
]
