_name1 = [
    'Rowlet', 'Dartrix', 'Decidueye', 'Litten', 'Torracat',
    'Incineroar', 'Popplio', 'Brionne', 'Primarina', 'Pikipek',
    'Trumbeak', 'Toucannon', 'Yungoos', 'Gumshoos', 'Grubbin',
    'Charjabug', 'Vikavolt', 'Crabrawler', 'Crabominable', 'Oricorio',
    'Cutiefly', 'Ribombee', 'Rockruff', 'Lycanroc', 'Wishiwashi',
    'Mareanie', 'Toxapex', 'Mudbray', 'Mudsdale', 'Dewpider',
    'Araquanid', 'Fomantis', 'Lurantis', 'Morelull', 'Shiinotic',
    'Salandit', 'Salazzle', 'Stufful', 'Bewear', 'Bounsweet',
]

_name2 = [
    'Steenee', 'Tsareena', 'Comfey', 'Oranguru', 'Passimian',
    'Wimpod', 'Golisopod', 'Sandygast', 'Palossand', 'Pyukumuku',
    'Type: Null', 'Silvally', 'Minior', 'Komala', 'Turtonator',
    'Togedemaru', 'Mimikyu', 'Bruxish', 'Drampa', 'Dhelmise',
    'Jangmo-o', 'Hakamo-o', 'Kommo-o', 'Tapu Koko', 'Tapu Lele',
    'Tapu Bulu', 'Tapu Fini', 'Cosmog', 'Cosmoem', 'Solgaleo',
    'Lunala', 'Nihilego', 'Buzzwole', 'Pheromosa', 'Xurkitree',
    'Celesteela', 'Kartana', 'Guzzlord', 'Necrozma', 'Magearna',
    'Marshadow',
]
