# -*- coding: utf-8 -*-

_name1 = [
    'Chikorita', 'Bayleef', 'Meganium', 'Cyndaquil', 'Quilava',
    'Typhlosion', 'Totodile', 'Croconaw', 'Feraligatr', 'Sentret',
    'Furret', 'Hoothoot', 'Noctowl', 'Ledyba', 'Ledian',
    'Spinarak', 'Ariados', 'Crobat', 'Chinchou', 'Lanturn',
    'Pichu', 'Cleffa', 'Igglybuff', 'Togepi', 'Togetic',
    'Natu', 'Xatu', 'Mareep', 'Flaaffy', 'Ampharos',
    'Bellossom', 'Marill', 'Azumarill', 'Sudowoodo', 'Politoed',
    'Hoppip', 'Skiploom', 'Jumpluff', 'Aipom', 'Sunkern',
    'Sunflora', 'Yanma', 'Wooper', 'Quagsire', 'Espeon',
    'Umbreon', 'Murkrow', 'Slowking', 'Misdreavus', 'Unown',
]

_name2 = [
    'Wobbuffet', 'Girafarig', 'Pineco', 'Forretress', 'Dunsparce',
    'Gligar', 'Steelix', 'Snubbull', 'Granbull', 'Qwilfish',
    'Scizor', 'Shuckle', 'Heracross', 'Sneasel', 'Teddiursa',
    'Ursaring', 'Slugma', 'Magcargo', 'Swinub', 'Piloswine',
    'Corsola', 'Remoraid', 'Octillery', 'Delibird', 'Mantine',
    'Skarmory', 'Houndour', 'Houndoom', 'Kingdra', 'Phanpy',
    'Donphan', 'Porygon2', 'Stantler', 'Smeargle', 'Tyrogue',
    'Hitmontop', 'Smoochum', 'Elekid', 'Magby', 'Miltank',
    'Blissey', 'Raikou', 'Entei', 'Suicune', 'Larvitar',
    'Pupitar', 'Tyranitar', 'Lugia', 'Ho-Oh', 'Celebi',
]
